@@ -1,6 +1,5 @@
 #!/bin/sh
 
-
 if [ $# != 1 ]; then
     echo "Wrong number of arguments"
     echo "fr_FR, en_US, ... is expected as argument"
@@ -18,6 +17,10 @@ if  ! test -f texi2scidoc; then
     exit
 fi
 
+if ! test -e $SCILAB_MAXDOC_DIR; then
+    mkdir -p $SCILAB_MAXDOC_DIR
+fi
+
 # this command generates listPnames.txt which contains personnalized names of
 # Maxima's functions
 scilab -nb -nw -nwni -f "genPnames.sce"
